@@ -21,7 +21,6 @@
 #include <boost/icl/interval_map.hpp>
 #include <boost/filesystem.hpp>
 #include <boost/tokenizer.hpp>
-#include <boost/progress.hpp>
 
 #include <htslib/sam.h>
 #include <htslib/vcf.h>
@@ -73,7 +72,9 @@ filterRun(TFilterConfig const& c) {
   bcf_hdr_t* hdr = bcf_hdr_read(ifile);
 
   // Open output VCF file
-  htsFile *ofile = hts_open(c.outfile.string().c_str(), "wb");
+  std::string fmtout = "wb";
+  if (c.outfile.string() == "-") fmtout = "w";
+  htsFile *ofile = hts_open(c.outfile.string().c_str(), fmtout.c_str());
   bcf_hdr_t *hdr_out = bcf_hdr_dup(hdr);
   if (c.filter == "somatic") {
     bcf_hdr_remove(hdr_out, BCF_HL_INFO, "RDRATIO");
@@ -117,7 +118,7 @@ filterRun(TFilterConfig const& c) {
 
   // Parse BCF
   boost::posix_time::ptime now = boost::posix_time::second_clock::local_time();
-  std::cout << '[' << boost::posix_time::to_simple_string(now) << "] " << "Filtering VCF/BCF file" << std::endl;
+  std::cerr << '[' << boost::posix_time::to_simple_string(now) << "] " << "Filtering VCF/BCF file" << std::endl;
   bcf1_t* rec = bcf_init1();
   while (bcf_read(ifile, hdr, rec) == 0) {
     bcf_unpack(rec, BCF_UN_INFO);
@@ -275,7 +276,7 @@ filterRun(TFilterConfig const& c) {
   hts_close(ofile);
 
   // Build index
-  bcf_index_build(c.outfile.string().c_str(), 14);
+  if (c.outfile.string() != "-") bcf_index_build(c.outfile.string().c_str(), 14);
 
   // Close VCF
   bcf_hdr_destroy(hdr);
@@ -283,7 +284,7 @@ filterRun(TFilterConfig const& c) {
 
   // End
   now = boost::posix_time::second_clock::local_time();
-  std::cout << '[' << boost::posix_time::to_simple_string(now) << "] Done." << std::endl;
+  std::cerr << '[' << boost::posix_time::to_simple_string(now) << "] Done." << std::endl;
 
   return 0;
 }
@@ -297,7 +298,7 @@ int filter(int argc, char **argv) {
   generic.add_options()
     ("help,?", "show help message")
     ("filter,f", boost::program_options::value<std::string>(&c.filter)->default_value("somatic"), "Filter mode (somatic, germline)")
-    ("outfile,o", boost::program_options::value<boost::filesystem::path>(&c.outfile)->default_value("sv.bcf"), "Filtered SV BCF output file")
+    ("outfile,o", boost::program_options::value<boost::filesystem::path>(&c.outfile), "Filtered SV BCF output file")
     ("altaf,a", boost::program_options::value<float>(&c.altaf)->default_value(0.2), "min. fractional ALT support")
     ("minsize,m", boost::program_options::value<int32_t>(&c.minsize)->default_value(0), "min. SV size")
     ("maxsize,n", boost::program_options::value<int32_t>(&c.maxsize)->default_value(500000000), "max. SV size")
@@ -341,9 +342,9 @@ int filter(int argc, char **argv) {
 
   // Check command line arguments
   if ((vm.count("help")) || (!vm.count("input-file"))) {
-    std::cout << std::endl;
-    std::cout << "Usage: delly " << argv[0] << " [OPTIONS] <input.bcf>" << std::endl;
-    std::cout << visible_options << "\n";
+    std::cerr << std::endl;
+    std::cerr << "Usage: delly " << argv[0] << " [OPTIONS] <input.bcf>" << std::endl;
+    std::cerr << visible_options << "\n";
     return 0;
   }
 
@@ -455,12 +456,20 @@ int filter(int argc, char **argv) {
     bcf_close(ifile);
   }
 
+  // Check outfile
+  if (!vm.count("outfile")) c.outfile = "-";
+  else {
+    if (c.outfile.string() != "-") {
+      if (!_outfileValid(c.outfile)) return 1;
+    }
+  }
+
   // Show cmd
   boost::posix_time::ptime now = boost::posix_time::second_clock::local_time();
-  std::cout << '[' << boost::posix_time::to_simple_string(now) << "] ";
-  std::cout << "delly ";
-  for(int i=0; i<argc; ++i) { std::cout << argv[i] << ' '; }
-  std::cout << std::endl;
+  std::cerr << '[' << boost::posix_time::to_simple_string(now) << "] ";
+  std::cerr << "delly ";
+  for(int i=0; i<argc; ++i) { std::cerr << argv[i] << ' '; }
+  std::cerr << std::endl;
 
   return filterRun(c);
 }
